@@ -8,19 +8,19 @@
 #include <errno.h>
 #include <stdio.h>
 #include <stdlib.h>
+#include <string.h>
 #include <fcntl.h>
+#include <sysexits.h>
 #include <sys/ioctl.h>
 #include <linux/kd.h>
-#include "getfd.h"
-#include "nls.h"
-#include "version.h"
-#include "kbd_error.h"
+
+#include "libcommon.h"
 
 static void __attribute__((noreturn))
-usage(void)
+usage(int rc)
 {
 	fprintf(stderr, _("usage: getkeycodes\n"));
-	exit(EXIT_FAILURE);
+	exit(rc);
 }
 
 int main(int argc, char **argv)
@@ -30,16 +30,13 @@ int main(int argc, char **argv)
 	struct kbkeycode a;
 
 	set_progname(argv[0]);
-
-	setlocale(LC_ALL, "");
-	bindtextdomain(PACKAGE_NAME, LOCALEDIR);
-	textdomain(PACKAGE_NAME);
+	setuplocale();
 
 	if (argc == 2 && !strcmp(argv[1], "-V"))
 		print_version_and_exit();
 
 	if (argc != 1)
-		usage();
+		usage(EX_USAGE);
 
 	if ((fd = getfd(NULL)) < 0)
 		kbd_error(EXIT_FAILURE, 0, _("Couldn't get a file descriptor referring to the console"));
@@ -67,7 +64,7 @@ int main(int argc, char **argv)
 		       sc0 - 1, sc0 - 1);
 	}
 
-	for (sc = (sc0 & ~7); sc < 256; sc++) {
+	for (sc = (sc0 & ~7U); sc < 256; sc++) {
 		if (sc == 128)
 			printf(_("\n\nEscaped scancodes e0 xx (hex)\n"));
 		if (sc % 8 == 0) {
